%global nautilus_extension_dir %{_datadir}/nautilus-python/extensions

Name:              winswitch
Summary:           Utility for controlling remote desktop sessions
URL:               http://winswitch.org/
Version:           0.12.21
Release:           5%{?dist}
License:           GPLv3
Source:            https://winswitch.org/src/%{name}-%{version}.src.tar.xz
BuildArch:         noarch

Requires:          pygtk2
Requires:          python-crypto
Requires:          python-twisted
Requires:          python-imaging
Requires:          python-xlib
Requires:          python-pyasn1
Requires:          python-utmp
Requires:          nautilus-python
Requires:          dbus-python
Requires:          dbus-x11
Requires:          gnome-python2
Requires:          gnome-python2-rsvg
Requires:          xpra
Requires:          nxproxy
Requires:          nxagent
Requires:          rdesktop
Requires:          openssh-clients
Requires:          tigervnc
Requires:          tigervnc-server >= 1.0.90
Requires:          avahi
Requires:          avahi-ui-tools
Requires:          gstreamer
Requires:          xloadimage
Requires:          devilspie
Requires:          ImageMagick
Requires:          gnome-menus
Requires:          xfreerdp
Requires:          java-vash

BuildRequires:     python2-devel
BuildRequires:     python-setuptools
BuildRequires:     desktop-file-utils
# Pull this in for the definition of %%{_javadir}
BuildRequires:     javapackages-tools

%description
Application to start and control remote GUI sessions via xpra, NX,
VNC, RDP or plain ssh X11 forwarding.  Winswitch can start, suspend,
resume and send supported sessions to other clients.


%prep
%setup -q

# Remove shebangs from py files
find winswitch -name \*.py -exec sed -i -e '1{\@^#!/usr/bin/env python@d}' '{}' \;

# Patch vash_util.py to use system vash
sed -i -e 's|VASH_JAR = os.path.join(SHARE_DIR, "Vash", "Vash.jar")|VASH_JAR = os.path.join("%{_javadir}", "Vash.jar")|g' winswitch/util/vash_util.py

%build
%{__python2} setup.py build


%install
%{__python2} setup.py install -O1 --prefix /usr --skip-build --root %{buildroot}

# Move the nautilus python extension to the correct location and fix perms
# https://projects-old.gnome.org/nautilus-python/documentation/html/nautilus-python-overview.html
mkdir -p %{buildroot}%{nautilus_extension_dir}
for file in %{buildroot}%{_prefix}/lib/nautilus/extensions-2.0/python/* ; do
    install -p -m 0644 ${file} %{buildroot}%{nautilus_extension_dir}
done
rm -rf %{buildroot}%{_prefix}/lib/nautilus

# Check desktop file
desktop-file-validate %{buildroot}/%{_datadir}/applications/winswitch.desktop

# Remove bundled vash
rm -rf %{buildroot}%{_datadir}/Vash


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

/bin/touch --no-create %{_datadir}/mime/packages &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

/usr/bin/update-desktop-database &> /dev/null || :

if [ $1 -eq 0 ] ; then
  /usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

/usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :


%files
%license COPYING
%{python2_sitelib}/winswitch
%{python2_sitelib}/winswitch*.egg-info
%{_bindir}/winswitch_*
%{_bindir}/wcw
%{_libexecdir}/winswitch
%dir %{_sysconfdir}/winswitch
%config(noreplace) %{_sysconfdir}/winswitch/server_defaults.conf
%config(noreplace) %{_sysconfdir}/winswitch/ports.conf
%config(noreplace) %{_sysconfdir}/winswitch/firewall
%{_datadir}/winswitch
%{_datadir}/Thunar
%{_datadir}/applications/winswitch.desktop
%{_datadir}/icons/hicolor/48x48/apps/*
%{_datadir}/icons/hicolor/64x64/apps/*
%{_datadir}/icons/winswitch*
%{_datadir}/man/man1/*
%{_datadir}/mime/packages/winswitch.xml
%{nautilus_extension_dir}/nautilus_winswitch.*


%changelog
* Tue Aug  4 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.12.21-5
- Use system Vash.jar

* Tue Aug  4 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.12.21-4
- Add Requires for nxagent

* Tue Aug  4 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.12.21-3
- Remove Requires for nx-libs
- Add Requires for nxproxy
- Mark config files as %%config(noreplace)
- Remove executable bit from the nautilus plugin script

* Wed Jul 15 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.12.21-2
- Untabify spec file

* Wed Jul 15 2015 Jonathan Underwood <jonathan.underwood@gmail.com> - 0.12.21-1
- Initial package

